@@ -1,17 +1,18 @@
 import datetime
 import json
 import os
+import pickle
 from collections import OrderedDict
 from io import StringIO
-import pandas as pd
 
 import jinja2
 import pandas
+import pandas as pd
 import plotly.graph_objs as go
 import requests
 import scipy.stats
 from plotly.offline import plot as offline_plot
-from shapely.geometry import Point, MultiPoint, box
+from shapely.geometry import Point, MultiPoint, shape
 from shapely.ops import nearest_points
 
 __all__ = ['forecast_stats', 'forecast_ensembles', 'forecast_warnings', 'forecast_records', 'historic_simulation',
@@ -449,12 +450,6 @@ def latlon_to_reach(lat: float, lon: float) -> dict:
     Return:
         a dictionary containing the reach_id as well as the name of the region and the distance
         from the provided lat and lon to the stream in units of degrees.
-
-    Example:
-        .. code-block:: python
-
-            stream_data = latlon_to_reach(10, 50)
-            {'reach_id': 123456, 'region': 'example_region-geoglows', 'distance': .05}
     """
     if lat is False or lon is False:
         raise ValueError('provide a valid latitude and longitude to in order to find a reach_id')
@@ -466,8 +461,8 @@ def latlon_to_reach(lat: float, lon: float) -> dict:
     point = Point(float(lat), float(lon))
 
     # open the region csv
-    base_path = os.path.abspath(os.path.join(os.path.dirname(__file__), 'delineation_data'))
-    df = pandas.read_csv(os.path.join(base_path, region, 'comid_lat_lon_z.csv'), sep=',', header=0, index_col=0)
+    base_path = os.path.abspath(os.path.join(os.path.dirname(__file__), 'geometry'))
+    df = pd.read_pickle(os.path.join(base_path, f'{region}-geoglows-comid_lat_lon_z.pickle'))
     points_df = df.loc[:, "Lat":"Lon"].apply(Point, axis=1)
 
     # determine which point is closest
@@ -493,23 +488,19 @@ def latlon_to_region(lat: float, lon: float) -> str:
 
     Return:
         the name of a region
-
-    Example:
-        .. code-block:: python
-
-            stream_data = latlon_to_region(10, 50)
     """
     if lat is False or lon is False:
         raise ValueError('provide a valid latitude and longitude to in order to find a region')
 
     # open the bounding boxes csv, figure out which regions the point lies within
     point = Point(float(lon), float(lat))
-    base_path = os.path.abspath(os.path.join(os.path.dirname(__file__), 'delineation_data'))
-    bb_csv = pandas.read_csv(os.path.join(base_path, 'bounding_boxes.csv'), index_col='region')
-    for row in bb_csv.iterrows():
-        bbox = box(row[1][0], row[1][1], row[1][2], row[1][3])
-        if point.within(bbox):
-            return row[0]
+    bounds_pickle = os.path.abspath(os.path.join(os.path.dirname(__file__), 'geometry', 'boundaries.pickle'))
+    with open(bounds_pickle, 'rb') as f:
+        region_bounds = json.loads(pickle.load(f))
+    for region in region_bounds:
+        for polygon in region_bounds[region]['features']:
+            if shape(polygon['geometry']).contains(point):
+                return region
     # if there weren't any regions, return that there was an error
     raise ValueError('This point is not within any of the supported delineation regions.')
 
